<?php

namespace App\Helpdesk;

use App\Models\Log;
use Barryvdh\Debugbar\Facades\Debugbar;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;

class Helper
{
    static function generatePassword($content)
    {
        return sha1(md5($content));
    }

    static function randomNumber($length) {
        $characters = '0123456789';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }

    static function randomString($length) {
        $characters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }

    static function generateStar($length) {
        $characters = '*';
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[0];
        }
        return $randomString;
    }

    static function contentStar($content){
        return  substr($content, 0, 1) . self::generateStar(strlen($content)-2) . substr($content,  -1);
    }

    static function permalink($str, $options = array())
    {
        $str = mb_convert_encoding((string)$str, 'UTF-8', mb_list_encodings());
        $defaults = array(
            'delimiter' => '-',
            'limit' => null,
            'lowercase' => true,
            'replacements' => array(),
            'transliterate' => true
        );
        $options = array_merge($defaults, $options);
        $char_map = array(
            // Latin
            'À' => 'A', 'Á' => 'A', 'Â' => 'A', 'Ã' => 'A', 'Ä' => 'A', 'Å' => 'A', 'Æ' => 'AE', 'Ç' => 'C',
            'È' => 'E', 'É' => 'E', 'Ê' => 'E', 'Ë' => 'E', 'Ì' => 'I', 'Í' => 'I', 'Î' => 'I', 'Ï' => 'I',
            'Ð' => 'D', 'Ñ' => 'N', 'Ò' => 'O', 'Ó' => 'O', 'Ô' => 'O', 'Õ' => 'O', 'Ö' => 'O', 'Ő' => 'O',
            'Ø' => 'O', 'Ù' => 'U', 'Ú' => 'U', 'Û' => 'U', 'Ü' => 'U', 'Ű' => 'U', 'Ý' => 'Y', 'Þ' => 'TH',
            'ß' => 'ss',
            'à' => 'a', 'á' => 'a', 'â' => 'a', 'ã' => 'a', 'ä' => 'a', 'å' => 'a', 'æ' => 'ae', 'ç' => 'c',
            'è' => 'e', 'é' => 'e', 'ê' => 'e', 'ë' => 'e', 'ì' => 'i', 'í' => 'i', 'î' => 'i', 'ï' => 'i',
            'ð' => 'd', 'ñ' => 'n', 'ò' => 'o', 'ó' => 'o', 'ô' => 'o', 'õ' => 'o', 'ö' => 'o', 'ő' => 'o',
            'ø' => 'o', 'ù' => 'u', 'ú' => 'u', 'û' => 'u', 'ü' => 'u', 'ű' => 'u', 'ý' => 'y', 'þ' => 'th',
            'ÿ' => 'y',
            // Latin symbols
            '©' => '(c)',
            // Greek
            'Α' => 'A', 'Β' => 'B', 'Γ' => 'G', 'Δ' => 'D', 'Ε' => 'E', 'Ζ' => 'Z', 'Η' => 'H', 'Θ' => '8',
            'Ι' => 'I', 'Κ' => 'K', 'Λ' => 'L', 'Μ' => 'M', 'Ν' => 'N', 'Ξ' => '3', 'Ο' => 'O', 'Π' => 'P',
            'Ρ' => 'R', 'Σ' => 'S', 'Τ' => 'T', 'Υ' => 'Y', 'Φ' => 'F', 'Χ' => 'X', 'Ψ' => 'PS', 'Ω' => 'W',
            'Ά' => 'A', 'Έ' => 'E', 'Ί' => 'I', 'Ό' => 'O', 'Ύ' => 'Y', 'Ή' => 'H', 'Ώ' => 'W', 'Ϊ' => 'I',
            'Ϋ' => 'Y',
            'α' => 'a', 'β' => 'b', 'γ' => 'g', 'δ' => 'd', 'ε' => 'e', 'ζ' => 'z', 'η' => 'h', 'θ' => '8',
            'ι' => 'i', 'κ' => 'k', 'λ' => 'l', 'μ' => 'm', 'ν' => 'n', 'ξ' => '3', 'ο' => 'o', 'π' => 'p',
            'ρ' => 'r', 'σ' => 's', 'τ' => 't', 'υ' => 'y', 'φ' => 'f', 'χ' => 'x', 'ψ' => 'ps', 'ω' => 'w',
            'ά' => 'a', 'έ' => 'e', 'ί' => 'i', 'ό' => 'o', 'ύ' => 'y', 'ή' => 'h', 'ώ' => 'w', 'ς' => 's',
            'ϊ' => 'i', 'ΰ' => 'y', 'ϋ' => 'y', 'ΐ' => 'i',
            // Turkish
            'Ş' => 'S', 'İ' => 'I', 'Ç' => 'C', 'Ü' => 'U', 'Ö' => 'O', 'Ğ' => 'G',
            'ş' => 's', 'ı' => 'i', 'ç' => 'c', 'ü' => 'u', 'ö' => 'o', 'ğ' => 'g',
            // Russian
            'А' => 'A', 'Б' => 'B', 'В' => 'V', 'Г' => 'G', 'Д' => 'D', 'Е' => 'E', 'Ё' => 'Yo', 'Ж' => 'Zh',
            'З' => 'Z', 'И' => 'I', 'Й' => 'J', 'К' => 'K', 'Л' => 'L', 'М' => 'M', 'Н' => 'N', 'О' => 'O',
            'П' => 'P', 'Р' => 'R', 'С' => 'S', 'Т' => 'T', 'У' => 'U', 'Ф' => 'F', 'Х' => 'H', 'Ц' => 'C',
            'Ч' => 'Ch', 'Ш' => 'Sh', 'Щ' => 'Sh', 'Ъ' => '', 'Ы' => 'Y', 'Ь' => '', 'Э' => 'E', 'Ю' => 'Yu',
            'Я' => 'Ya',
            'а' => 'a', 'б' => 'b', 'в' => 'v', 'г' => 'g', 'д' => 'd', 'е' => 'e', 'ё' => 'yo', 'ж' => 'zh',
            'з' => 'z', 'и' => 'i', 'й' => 'j', 'к' => 'k', 'л' => 'l', 'м' => 'm', 'н' => 'n', 'о' => 'o',
            'п' => 'p', 'р' => 'r', 'с' => 's', 'т' => 't', 'у' => 'u', 'ф' => 'f', 'х' => 'h', 'ц' => 'c',
            'ч' => 'ch', 'ш' => 'sh', 'щ' => 'sh', 'ъ' => '', 'ы' => 'y', 'ь' => '', 'э' => 'e', 'ю' => 'yu',
            'я' => 'ya',
            // Ukrainian
            'Є' => 'Ye', 'І' => 'I', 'Ї' => 'Yi', 'Ґ' => 'G',
            'є' => 'ye', 'і' => 'i', 'ї' => 'yi', 'ґ' => 'g',
            // Czech
            'Č' => 'C', 'Ď' => 'D', 'Ě' => 'E', 'Ň' => 'N', 'Ř' => 'R', 'Š' => 'S', 'Ť' => 'T', 'Ů' => 'U',
            'Ž' => 'Z',
            'č' => 'c', 'ď' => 'd', 'ě' => 'e', 'ň' => 'n', 'ř' => 'r', 'š' => 's', 'ť' => 't', 'ů' => 'u',
            'ž' => 'z',
            // Polish
            'Ą' => 'A', 'Ć' => 'C', 'Ę' => 'e', 'Ł' => 'L', 'Ń' => 'N', 'Ó' => 'o', 'Ś' => 'S', 'Ź' => 'Z',
            'Ż' => 'Z',
            'ą' => 'a', 'ć' => 'c', 'ę' => 'e', 'ł' => 'l', 'ń' => 'n', 'ó' => 'o', 'ś' => 's', 'ź' => 'z',
            'ż' => 'z',
            // Latvian
            'Ā' => 'A', 'Č' => 'C', 'Ē' => 'E', 'Ģ' => 'G', 'Ī' => 'i', 'Ķ' => 'k', 'Ļ' => 'L', 'Ņ' => 'N',
            'Š' => 'S', 'Ū' => 'u', 'Ž' => 'Z',
            'ā' => 'a', 'č' => 'c', 'ē' => 'e', 'ģ' => 'g', 'ī' => 'i', 'ķ' => 'k', 'ļ' => 'l', 'ņ' => 'n',
            'š' => 's', 'ū' => 'u', 'ž' => 'z'
        );
        $str = preg_replace(array_keys($options['replacements']), $options['replacements'], $str);
        if ($options['transliterate']) {
            $str = str_replace(array_keys($char_map), $char_map, $str);
        }
        $str = preg_replace('/[^\p{L}\p{Nd}]+/u', $options['delimiter'], $str);
        $str = preg_replace('/(' . preg_quote($options['delimiter'], '/') . '){2,}/', '$1', $str);
        $str = mb_substr($str, 0, ($options['limit'] ? $options['limit'] : mb_strlen($str, 'UTF-8')), 'UTF-8');
        $str = trim($str, $options['delimiter']);
        return $options['lowercase'] ? mb_strtolower($str, 'UTF-8') : $str;
    }

    static function seflink($text){
        $find = array("/Ğ/","/Ü/","/Ş/","/İ/","/Ö/","/Ç/","/ğ/","/ü/","/ş/","/ı/","/ö/","/ç/");
        $degis = array("G","U","S","I","O","C","g","u","s","i","o","c");
        $text = preg_replace("/[^0-9a-zA-ZÄzÜŞİÖÇğüşıöç]/"," ",$text);
        $text = preg_replace($find,$degis,$text);
        $text = preg_replace("/ +/"," ",$text);
        $text = preg_replace("/ /","-",$text);
        $text = preg_replace("/\s/","",$text);
        $text = strtolower($text);
        $text = preg_replace("/^-/","",$text);
        $text = preg_replace("/-$/","",$text);
        return $text;
    }

    static function getBrowser(){
        $u_agent = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '';
        $bname = 'Unknown';
        $platform = 'Unknown';
        $version= "";

        //First get the platform?
        if (preg_match('/linux/i', $u_agent)) {
            $platform = 'linux';
        }
        elseif (preg_match('/macintosh|mac os x/i', $u_agent)) {
            $platform = 'mac';
        }
        elseif (preg_match('/windows|win32/i', $u_agent)) {
            $platform = 'windows';
        }

        // Next get the name of the useragent yes seperately and for good reason

        $ub = '';
        if(preg_match('/MSIE/i',$u_agent) && !preg_match('/Opera/i',$u_agent))
        {
            $bname = 'Internet Explorer';
            $ub = "MSIE";
        }
        elseif(preg_match('/Firefox/i',$u_agent))
        {
            $bname = 'Mozilla Firefox';
            $ub = "Firefox";
        }
        elseif(preg_match('/Chrome/i',$u_agent))
        {
            $bname = 'Google Chrome';
            $ub = "Chrome";
        }
        elseif(preg_match('/Safari/i',$u_agent))
        {
            $bname = 'Apple Safari';
            $ub = "Safari";
        }
        elseif(preg_match('/Opera/i',$u_agent))
        {
            $bname = 'Opera';
            $ub = "Opera";
        }
        elseif(preg_match('/Netscape/i',$u_agent))
        {
            $bname = 'Netscape';
            $ub = "Netscape";
        }

        // finally get the correct version number
        $known = array('Version', $ub, 'other');
        $pattern = '#(?<browser>' . join('|', $known) .
            ')[/ ]+(?<version>[0-9.|a-zA-Z.]*)#';
        if (!preg_match_all($pattern, $u_agent, $matches)) {
            // we have no matching number just continue
        }

        // see how many we have
        $i = count($matches['browser']);
        if ($i != 1) {
            //we will have two since we are not using 'other' argument yet
            //see if version is before or after the name
            if (strripos($u_agent,"Version") < strripos($u_agent,$ub)){
                $version= isset($matches['version'][0]) ? $matches['version'][0] : '';
            }
            else {
                $version= isset($matches['version'][1]) ? $matches['version'][1] : '';
            }
        }
        else {
            $version= isset($matches['version'][0]) ? $matches['version'][0] : '';
        }

        // check if we have a number
        if ($version==null || $version=="") {$version="?";}

        /*
        return array(
            'name'      => $bname,
            'version'   => $version,
            'platform'  => $platform
        );*/

        return $platform." - ".$bname." / ".$version;
    }


    static function getIp(){
        return \Request::ip();
    }

    static function getTime($unit){

        date_default_timezone_set('Europe/Istanbul');
        $today = getdate();

        if($unit == 'hour'){

            $hour = ($today['hours'] - 1).":".date('i');

            return $hour;

        }

    }

    static function convertDate($date , $character){

        $date = explode($character,$date);

        $date = $date[2].'/'.$date[1];

        return $date;

    }

    static function convertComma($number){

        $number = (string)$number;

        $number = str_replace(".",",",$number);

        return $number;

    }

    static function usdFormat($number){
        return number_format((float)$number, 3, '.', ',');
    }

    static function coinFormat($number){
        return number_format((float)$number, 8, '.', ',');
    }

    static function setLog(\Exception $exception, $type = 'i' , $request = '', $user_id = -1){

        $user = $user_id;//$request->user() != null ? $request->user()->id : $user_id;

        $log_data = [
            'user_id' => $user,
            'desc' => $exception->getMessage(),
            'line' => $exception->getLine(),
            'request' => $request,
            'type' => $type,
            'ip' => Helper::getIp(),
            'browser' => Helper::getBrowser()
        ];

        $log = Log::create($log_data);

        $fp = fopen(Storage::path('logs.csv'), 'a');

        $log->new_object = null;
        $log->request = null;
        fputcsv($fp, $log->toArray());

        fclose($fp);

        if($log){
            return true;
        }else{
            return false;
        }

    }

    static function setLastLogin($user_id, $type = '1', $platform){
        $log_data = [
            'user_id' => $user_id,
            'type' => $type,
            'browser' => Helper::getBrowser(),
            'platform' => $platform,
            'ip' => Helper::getIp()
        ];

        $last_login = LastLogin::create($log_data);

        $fp = fopen(Storage::path('last_logins.csv'), 'a');

        $last_login->new_object = null;
        fputcsv($fp, $last_login->toArray());

        fclose($fp);

        if($last_login){
            return true;
        }else{
            return false;
        }

    }

    static function set2Digit($val){
        return number_format((float)$val, 2, '.', '');
    }

    static function set8Digit($val){
        return number_format((float)$val, 8, '.', '');
    }

    static function luhn_check($number) {

        // Strip any non-digits (useful for credit card numbers with spaces and hyphens)
        $number=preg_replace('/\D/', '', $number);

        // Set the string length and parity
        $number_length=strlen($number);
        $parity=$number_length % 2;

        // Loop through each digit and do the maths
        $total=0;
        for ($i=0; $i<$number_length; $i++) {
            $digit=$number[$i];
            // Multiply alternate digits by two
            if ($i % 2 == $parity) {
                $digit*=2;
                // If the sum is two digits, add them together (in effect)
                if ($digit > 9) {
                    $digit-=9;
                }
            }
            // Total up the digits
            $total+=$digit;
        }

        // If the total mod 10 equals 0, the number is valid
        return ($total % 10 == 0) ? TRUE : FALSE;

    }

    static function get_main_type($type){
        switch ($type){
            case '1':
                return 'Giden Transfer';
                break;
            case '2':
                return 'Gelen Transfer';
                break;
            case '3':
                return 'Gönderilen Para İsteği';
                break;
            case '4':
                return 'Para Çekim Talebi';
                break;
            case '5':
                return 'Para Yatırma Talebi';
                break;
            case '6':
                return 'Fatura Ödeme';
                break;
            case '7':
                return 'Üye İş Yeri Yapılan Ödeme';
                break;
            case '8':
                return 'Üye İş Yeri Alınan Ödeme';
                break;
            case '9':
                return 'İade Edilen';
                break;
            default:
                return '';
                break;
        }

    }

    static function get_Ip(){
        foreach (array('HTTP_CLIENT_IP', 'HTTP_X_FORWARDED_FOR', 'HTTP_X_FORWARDED', 'HTTP_X_CLUSTER_CLIENT_IP', 'HTTP_FORWARDED_FOR', 'HTTP_FORWARDED', 'REMOTE_ADDR', 'HTTP_CF_CONNECTING_IP') as $key){
            if (array_key_exists($key, $_SERVER) === true){
                foreach (explode(',', $_SERVER[$key]) as $ip){
                    $ip = trim($ip); // just to be safe
                    if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_NO_PRIV_RANGE | FILTER_FLAG_NO_RES_RANGE) !== false){
                        return $ip;
                    }
                }
            }
        }
        return $_SERVER;
    }

    /*static function send_sms($user_id, $phone, $text){

        $postUrl = "http://panel.1sms.com.tr:8080/api/smsget/v1?username=PARAQR&password=78d7c1a53168b9678102c32bea974b66&header=PARAQR&gsm=" . $phone . "&message=" . urlencode($text);

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $postUrl);
        curl_setopt($ch, CURLOPT_TIMEOUT, 5);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);

        $response = curl_exec($ch);
        curl_close($ch);

        DB::beginTransaction();
        try {
            $sms_log = SmsLog::create([
                'user_id' => $user_id,
                'header' => 'PARAQR',
                'phone' => $phone,
                'message' => $text
            ]);
            DB::commit();

            $fp = fopen(Storage::path('sms_logs.csv'), 'a');

            $sms_log->new_object = null;
            fputcsv($fp, $sms_log->toArray());

            fclose($fp);

        }catch (\Exception $exception){
            DB::rollBack();
            Helper::setLog($exception, 'e', '');
        }

        if (substr($response, 0, 2) == "00") {
            return true;
        } else {
            return false;
        }
    }*/

    static function name_surname($text, $type){
        $names = explode(' ', $text);

        if ($type == 'n'){
            $name = '';

            for ($i = 0; $i < count($names)-1; $i++){
                $name .= $names[$i].' ';
            }

            return trim($name);
        }

        if ($type == 's'){
            return $names[count($names)-1];
        }
    }

    static function send_sms($user_id, $phone, $text){
        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => 'https://api.netgsm.com.tr/sms/send/get',
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => 'POST',
            CURLOPT_POSTFIELDS => array('usercode' => '8503049635','password' => 'Wc.q1w2e3r4','gsmno' => $phone,'message' => $text,'msgheader' => 'SWIFTDCTECH','filter' => '0'),
        ));

        $response = curl_exec($curl);

        curl_close($curl);

        $log = new Log();

        $log->user_id = $user_id;
        $log->description = $text;
        $log->errors = $response;

        $log->save();

        if ($response == '20') {
            return false;
        }else if ($response == '30') {
            return false;
        }else if ($response == '40') {
            return false;
        }else if ($response == '50') {
            return false;
        }else if ($response == '51') {
            return false;
        }else if ($response == '70') {
            return false;
        }else if ($response == '80') {
            return false;
        }else if ($response == '85') {
            return false;
        }else if ($response == '100-101') {
            return false;
        }else {
            return true;
        }
    }

    static function sendNotificationToUser($content, $oneSignalUserId, $url = null, $data = null, $buttons = null, $schedule = null, $user_id){
        try {
            \OneSignal::sendNotificationToUser(
                $content,
                $oneSignalUserId,
                $url,
                $data,
                $buttons,
                $schedule
            );

            DB::beginTransaction();
            try {
                $notification_log = NotificationLog::create([
                    'user_id' => $user_id,
                    'content' => $content,
                    'oneSignalUserId' => $oneSignalUserId,
                    'url' => $url,
                    'data' => $data,
                    'buttons' => $buttons,
                    'schedule' => $schedule
                ]);

                DB::commit();
            }catch (\Exception $exception){
                DB::rollBack();
                Helper::setLog($exception, 'e', '');
            }
        }catch (\Exception $exception){
            Helper::setLog($exception, 'e', '');
        }
    }

    static function toInput($info){
        switch ($info->data_type){
            case '0';
                return '<div class="mb-2">
                            <label class="form-label">'.$info->title.'</label>
                            <input class="form-control" type="text" name="'.$info->parameter_name.'" placeholder="'.$info->title.'">
                        </div>';
            default;
                return '';
        }
    }

    static function phoneLink($text){
        if ($text != ""){
            if (str_starts_with($text, "+")){
                return $text;
            }else if (str_starts_with($text, "9")){
                return "0".$text;
            }else if (str_starts_with($text, "0")){
                return $text;
            }else{
                return "0".$text;
            }
        }else{
            return $text;
        }
    }

    static function getInvoiceStatus($status){
        if ($status === '0'){
            return 'Oluşturuldu';
        }else if ($status === '1'){
            return 'Ödeme Yapıldı';
        }else if ($status === '2') {
            return 'Onaylandı';
        }else if ($status === '3'){
            return 'Baskı Sürecinde';
        }else if ($status === '4'){
            return 'Baskı Tamamlandı';
        }else if ($status === '5'){
            return 'Gönderildi';
        }else if ($status === '6'){
            return 'Tamamlandı';
        }else if ($status === '7'){
            return 'İptal';
        }else if ($status === '8'){
            return 'Süresi Doldu';
        }else if ($status === '9'){
            return 'Reddedildi';
        }else {
            return '';
        }
    }

    static function getInvoiceStatusBadge($status){
        if ($status === '0'){
            return 'warning';
        }else if ($status === '1'){
            return 'success';
        }else if ($status === '2') {
            return 'primary';
        }else if ($status === '3'){
            return 'primary';
        }else if ($status === '4'){
            return 'primary';
        }else if ($status === '5'){
            return 'primary';
        }else if ($status === '6'){
            return 'primary';
        }else if ($status === '7'){
            return 'primary';
        }else if ($status === '8'){
            return 'primary';
        }else if ($status === '9'){
            return 'primary';
        }else {
            return '';
        }
    }

    static function comissionCalculate($order){
        $comissionTable = [
              "lvl.0" => [99, [ 90, 136, 181 ]],
              "lvl.1" => [150, [ 92, 138, 183 ]],
              "lvl.2" => [250, [ 95, 141, 186 ]],
              "lvl.3" => [500, [ 97, 143, 188 ]],
              "lvl.4" => [1000, [ 100, 146, 191 ]],
              "lvl.5" => [3000, [ 105, 151, 196 ]],
              "lvl.6" => [5000, [ 105, 151, 196 ]],
              "lvl.7" => [15000, [ 115, 161, 206 ]],
              "lvl.8" => [25000, [ 140, 186, 231 ]],
              "lvl.9" => [50000, [ 140, 186, 231 ]],
              "lvl.10" => [null, [ 140, 186, 231 ]],
        ];

        $additionalComissionTable = [
              "lvl.0" => [100, [ 20, 35, 50 ]],
              "lvl.1" => [150, [ 20, 35, 50 ]],
              "lvl.2" => [250, [ 20, 35, 50 ]],
              "lvl.3" => [500, [ 20, 35, 50 ]],
              "lvl.4" => [1000, [ 20, 35, 50 ]],
              "lvl.5" => [2000, [ 20, 35, 50 ]],
              "lvl.6" => [5000, [ 20, 35, 50 ]],
              "lvl.7" => [10000, [ 20, 35, 50 ]],
              "lvl.8" => [25000, [ 20, 35, 50 ]],
              "lvl.9" => [50000, [ 20, 35, 50 ]],
              "lvl.10" => [null, [ 20, 35, 50 ]],
        ];

        $earn = 0;

        $total_card = $order->count_order;
        $left = $total_card;

        foreach ($comissionTable as $item){
            if ($left > 0){
                if ($item[0] > 0){
                    $item_0 = $item[0];
                    $left_0 = $left;
                    $calc = $item[0] - $left;
                    $item[0] = max($calc, 0);
                    $left = abs($calc) > 0 ? abs($calc) : 0;

                    $earn += (($item_0 - $left_0) > 0 ? $left_0 : $item_0) * $item[1][$order->product->comission_category];

                    DebugBar::info($total_card.' '.$calc.' '.$left.' '.$left_0.' '.$item[0].' '.$item_0.' '.$item[1][$order->product->comission_category].' '.$earn.' ');

                    if (($item_0 - $left_0) > 0){
                        break;
                    }
                }
            }
        }

        $additionalCount = $order->sum_quantity - $order->count_order;

        $total_card = $additionalCount;
        $left = $additionalCount;

        if ($additionalCount > 0) {
            foreach ($additionalComissionTable as $item) {
                if ($left > 0) {
                    if ($item[0] > 0) {
                        $item_0 = $item[0];
                        $left_0 = $left;
                        $calc = $item[0] - $left;
                        $item[0] = max($calc, 0);
                        $left = abs($calc) > 0 ? abs($calc) : 0;

                        $earn += (($item_0 - $left_0) > 0 ? $left_0 : $item_0) * $item[1][$order->product->comission_category];

                        DebugBar::info($total_card . ' ' . $calc . ' ' . $left . ' ' . $left_0 . ' ' . $item[0] . ' ' . $item_0 . ' ' . $item[1][$order->product->comission_category] . ' ' . $earn . ' ');

                        if (($item_0 - $left_0) > 0) {
                            break;
                        }
                    }
                }
            }
        }

        return $earn;
    }

    static function leaderComissionCalculate($order){
        $comissionTable = [
              "lvl.0" => [0, 500000, 0.5],
              "lvl.1" => [500001, 2500000, 1],
              "lvl.2" => [2500001, 10000000, 1.5],
              "lvl.3" => [10000001, null, 2]
        ];

        $earn = 0;

        foreach ($comissionTable as $item){
            if ($order->count_order >= $item[0] && ($item[1] != null ? ($order->count_order <= $item[1]) : true)){
                $earn += $order->count_order * $item[2][$order->product->comission_category];
            }
        }

        return $earn;
    }

    static function human_filesize($bytes, $decimals = 2) {
        $sz = 'BKMGTP';
        $factor = floor((strlen($bytes) - 1) / 3);
        return sprintf("%.{$decimals}f", $bytes / pow(1024, $factor)) . @$sz[$factor];
    }

    static function getUserAgent(){
        $data = array('.*Java.*outbrain', ' YLT', '^b0t$', '^bluefish ', '^Calypso v\/', '^COMODO DCV', '^DangDang', '^DavClnt', '^FDM ', '^git\/', '^Goose\/', '^Grabber', '^HTTPClient\/', '^Java\/', '^Jeode\/', '^Jetty\/', '^Mail\/', '^Mget', '^Microsoft URL Control', '^NG\/[0-9\.]', '^NING\/', '^PHP\/[0-9]', '^RMA\/', '^Ruby|Ruby\/[0-9]', '^VSE\/[0-9]', '^WordPress\.com', '^XRL\/[0-9]', '^ZmEu', '008\/', '13TABS', '192\.comAgent', '2ip\.ru', '404enemy', '7Siters', '80legs', 'a\.pr-cy\.ru', 'a3logics\.in', 'A6-Indexer', 'Abonti', 'Aboundex', 'aboutthedomain', 'Accoona-AI-Agent', 'acoon', 'acrylicapps\.com\/pulp', 'Acunetix', 'AdAuth\/', 'adbeat', 'AddThis', 'ADmantX', 'AdminLabs', 'adressendeutschland', 'adscanner', 'Adstxtaggregator', 'adstxt-worker', 'adstxt\.com', 'agentslug', 'AHC', 'aihit', 'aiohttp\/', 'Airmail', 'akka-http\/', 'akula\/', 'alertra', 'alexa site audit', 'Alibaba\.Security\.Heimdall', 'Alligator', 'allloadin', 'AllSubmitter', 'alyze\.info', 'amagit', 'Anarchie', 'AndroidDownloadManager', 'Anemone', 'AngleSharp', 'annotate_google', 'Ant\.com', 'Anturis Agent', 'AnyEvent-HTTP\/', 'Apache Droid', 'Apache OpenOffice', 'Apache-HttpAsyncClient', 'Apache-HttpClient', 'ApacheBench', 'Apexoo', 'APIs-Google', 'AportWorm\/', 'AppBeat\/', 'AppEngine-Google', 'AppleSyndication', 'AppStoreScraperZ', 'Aprc\/[0-9]', 'Arachmo', 'arachnode', 'Arachnophilia', 'aria2', 'Arukereso', 'asafaweb', 'AskQuickly', 'Ask Jeeves', 'ASPSeek', 'Asterias', 'Astute', 'asynchttp', 'Attach', 'autocite', 'AutomaticWPTester', 'Autonomy', 'axios\/', 'B-l-i-t-z-B-O-T', 'Backlink-Ceck', 'backlink-check', 'BacklinkHttpStatus', 'BackStreet', 'BackWeb', 'Bad-Neighborhood', 'Badass', 'baidu\.com', 'Bandit', 'basicstate', 'BatchFTP', 'Battleztar Bazinga', 'baypup\/', 'BazQux', 'BBBike', 'BCKLINKS', 'BDFetch', 'BegunAdvertising', 'Bidtellect', 'BigBozz', 'Bigfoot', 'biglotron', 'BingLocalSearch', 'BingPreview', 'binlar', 'biNu image cacher', 'Bitacle', 'biz_Directory', 'Black Hole', 'Blackboard Safeassign', 'BlackWidow', 'BlockNote\.Net', 'Bloglines', 'Bloglovin', 'BlogPulseLive', 'BlogSearch', 'Blogtrottr', 'BlowFish', 'boitho\.com-dc', 'BPImageWalker', 'Braintree-Webhooks', 'Branch Metrics API', 'Branch-Passthrough', 'Brandprotect', 'BrandVerity', 'Brandwatch', 'Brodie\/', 'Browsershots', 'BUbiNG', 'Buck\/', 'Buddy', 'BuiltWith', 'Bullseye', 'BunnySlippers', 'Burf Search', 'Butterfly\/', 'BuzzSumo', 'CAAM\/[0-9]', 'CakePHP', 'Calculon', 'Canary%20Mail', 'CaretNail', 'catexplorador', 'CC Metadata Scaper', 'Cegbfeieh', 'censys', 'Cerberian Drtrs', 'CERT\.at-Statistics-Survey', 'cg-eye', 'changedetection', 'ChangesMeter', 'Charlotte', 'CheckHost', 'checkprivacy', 'CherryPicker', 'ChinaClaw', 'Chirp\/', 'chkme\.com', 'Chlooe', 'Chromaxa', 'CirrusExplorer', 'CISPA Vulnerability Notification', 'Citoid', 'CJNetworkQuality', 'Clarsentia', 'clips\.ua\.ac\.be', 'Cloud mapping', 'CloudEndure', 'CloudFlare-AlwaysOnline', 'Cloudinary', 'cmcm\.com', 'coccoc', 'cognitiveseo', 'colly -', 'CommaFeed', 'Commons-HttpClient', 'commonscan', 'contactbigdatafr', 'contentkingapp', 'convera', 'CookieReports', 'copyright sheriff', 'CopyRightCheck', 'Copyscape', 'Cosmos4j\.feedback', 'Covario-IDS', 'Craw\/', 'Crescent', 'Crowsnest', 'Criteo', 'CSHttp', 'CSSCheck', 'curb', 'Curious George', 'curl', 'cuwhois\/', 'cybo\.com', 'DAP\/NetHTTP', 'DareBoost', 'DatabaseDriverMysqli', 'DataCha0s', 'Datafeedwatch', 'Datanyze', 'DataparkSearch', 'dataprovider', 'DataXu', 'Daum(oa)?[ \/][0-9]', 'dBpoweramp', 'ddline', 'deeris', 'Demon', 'DeuSu', 'developers\.google\.com\/\+\/web\/snippet\/', 'Devil', 'Digg', 'Digincore', 'DigitalPebble', 'Dirbuster', 'Discourse Forum Onebox', 'Disqus\/', 'Dispatch\/', 'DittoSpyder', 'dlvr', 'DMBrowser', 'DNSPod-reporting', 'docoloc', 'Dolphin http client', 'DomainAppender', 'Donuts Content Explorer', 'dotMailer content retrieval', 'dotSemantic', 'downforeveryoneorjustme', 'Download Wonder', 'downnotifier', 'DowntimeDetector', 'Drip', 'drupact', 'Drupal \(\+http:\/\/drupal\.org\/\)', 'DTS Agent', 'dubaiindex', 'DuplexWeb-Google', 'EARTHCOM', 'Easy-Thumb', 'EasyDL', 'Ebingbong', 'ec2linkfinder', 'eCairn-Grabber', 'eCatch', 'ECCP', 'eContext\/', 'Ecxi', 'EirGrabber', 'ElectricMonk', 'elefent', 'EMail Exractor', 'EMail Wolf', 'EmailWolf', 'Embarcadero', 'Embed PHP Library', 'Embedly', 'endo\/', 'europarchive\.org', 'evc-batch', 'EventMachine HttpClient', 'Everwall Link Expander', 'Evidon', 'Evrinid', 'ExactSearch', 'ExaleadCloudview', 'Excel\/', 'exif', 'Exploratodo', 'Express WebPictures', 'Extreme Picture Finder', 'EyeNetIE', 'ezooms', 'facebookexternalhit', 'facebookexternalua', 'facebookplatform', 'fairshare', 'Faraday v', 'fasthttp', 'Faveeo', 'Favicon downloader', 'faviconkit', 'faviconarchive', 'FavOrg', 'Feed Wrangler', 'Feedable\/', 'Feedbin', 'FeedBooster', 'FeedBucket', 'FeedBunch\/', 'FeedBurner', 'feeder', 'Feedly', 'FeedshowOnline', 'Feedspot', 'Feedwind\/', 'FeedZcollector', 'feeltiptop', 'Fetch API', 'Fetch\/[0-9]', 'Fever\/[0-9]', 'FHscan', 'Fimap', 'findlink', 'findthatfile', 'FlashGet', 'FlipboardBrowserProxy', 'FlipboardProxy', 'FlipboardRSS', 'Flock\/', 'fluffy', 'Flunky', 'flynxapp', 'forensiq', 'FoundSeoTool', 'http:\/\/www.neomo.de\/', 'free thumbnails','Freeuploader','Funnelback','G-i-g-a-b-o-t','g00g1e\.net','ganarvisitas','geek-tools','Genieo','GentleSource','GetCode','Getintent','GetLinkInfo','getprismatic','GetRight','getroot','GetURLInfo\/','GetWeb','Geziyor','Ghost Inspector','GigablastOpenSource','GIS-LABS','github-camo','github\.com','Go [\d\.]* package http','Go http package','Go-Ahead-Got-It','Go-http-client','Go!Zilla','gobyus','gofetch','GomezAgent','gooblog','Goodzer\/','Google AppsViewer','Google Desktop','Google favicon','Google Keyword Suggestion','Google Keyword Tool','Google Page Speed Insights','Google PP Default','Google Search Console','Google Web Preview','Google-Adwords','Google-Apps-Script','Google-Calendar-Importer','Google-HotelAdsVerifier','Google-HTTP-Java-Client','Google-Publisher-Plugin','Google-Read-Aloud','Google-SearchByImage','Google-Site-Verification','Google-Structured-Data-Testing-Tool','Google-Youtube-Links','google-xrawler','GoogleDocs','GoogleHC\/','GoogleProducer','GoogleSites','Google-Transparency-Report','Gookey','GoScraper','GoSpotCheck','gosquared-thumbnailer','Gotit','GoZilla','grabify','GrabNet','Grafula','Grammarly','GrapeFX','GreatNews','Gregarius','GRequests','grokkit','grouphigh','grub-client','gSOAP\/','GT::WWW','GTmetrix','GuzzleHttp','gvfs\/','HAA(A)?RTLAND http client','Haansoft','hackney\/','Hadi Agent','HappyApps-WebCheck','Hatena','Havij','HeadlessChrome','HEADMasterSEO','HeartRails_Capture','help@dataminr\.com','heritrix','historious','hkedcity','hledejLevne\.cz','Hloader','HMView','Holmes','HonesoSearchEngine','HootSuite Image proxy','Hootsuite-WebFeed','hosterstats','HostTracker','ht:\/\/check','htdig','HTMLparser','htmlyse','HTTP Banner Detection','HTTP_Compression_Test','http_request2','http_requester','http-get','HTTP-Header-Abfrage','http-kit','http-request\/','HTTP-Tiny','HTTP::Lite','http\.rb\/','http_get','HttpComponents','httphr','HTTPMon','HTTPie','httpRequest','httpscheck','httpssites_power','httpunit','HttpUrlConnection','httrack','huaweisymantec','HubSpot ','Humanlinks','i2kconnect\/','Iblog','ichiro','Id-search','IdeelaborPlagiaat','IDG Twitter Links Resolver','IDwhois\/','Iframely','igdeSpyder','IlTrovatore','Image Fetch','Image Sucker','ImageEngine\/','ImageVisu\/','Imagga','imagineeasy','imgsizer','InAGist','inbound\.li parser','InDesign%20CC','Indy Library','InetURL','infegy','infohelfer','InfoTekies','InfoWizards Reciprocal Link','inpwrd\.com','instabid','Instapaper','Integrity','integromedb','Intelliseek','InterGET','internet_archive','Internet Ninja','InternetSeer','internetVista monitor','internetwache','intraVnews','IODC','IOI','iplabel','ips-agent','IPS\/[0-9]','IPWorks HTTP\/S Component','iqdb\/','Iria','Irokez','isitup\.org','iskanie','isUp\.li','iThemes Sync\/','IZaBEE','iZSearch','JAHHO','janforman','Jaunt\/','Jbrofuzz','Jersey\/','JetCar','Jigsaw','Jobboerse','JobFeed discovery','Jobg8 URL Monitor','jobo','Jobrapido','Jobsearch1\.5','JoinVision Generic','JolokiaPwn','Joomla','Jorgee','JS-Kit','JustView','Kaspersky Lab CFR link resolver','Kelny\/','Kerrigan\/','KeyCDN','Keyword Density','Keywords Research','khttp\/','KickFire','KimonoLabs\/','Kml-Google','knows\.is','KOCMOHABT','kouio','kube-probe','kulturarw3','KumKie','L\.webis','Larbin','Lavf\/','LeechFTP','LeechGet','letsencrypt','Lftp','LibVLC','LibWeb','Libwhisker','libwww','Licorne','Liferea\/','Lightspeedsystems','Lighthouse','Likse','Link Valet','link_thumbnailer','LinkAlarm\/','linkCheck','linkdex','LinkExaminer','linkfluence','linkpeek','LinkPreviewGenerator','LinkScan','LinksManager','LinkTiger','LinkWalker','Lipperhey','Litemage_walker','livedoor ScreenShot','LoadImpactRload','localsearch-web','LongURL API','looid\.com','looksystems\.net','ltx71','lua-resty-http','lwp-request','lwp-trivial','LWP::Simple','lycos','LYT\.SR','mabontland','Mag-Net','MagpieRSS','Mail\.Ru','MailChimp','Majestic12','makecontact\/','Mandrill','MapperCmd','marketinggrader','MarkMonitor','MarkWatch','Mass Downloader','masscan\/','Mata Hari','Mediametric','Mediapartners-Google','mediawords','MegaIndex\.ru','MeltwaterNews','Melvil Rawi','MemGator','Metaspinner','MetaURI','MFC_Tear_Sample','Microsearch','Microsoft Office ','Microsoft Outlook','Microsoft Windows Network Diagnostics','Microsoft-WebDAV-MiniRedir','Microsoft Data Access','MIDown tool','MIIxpc','Mindjet','Miniature\.io','Miniflux','Mister PiX','mixdata dot com','mixed-content-scan','Mixmax-LinkPreview','mixnode','Mnogosearch','mogimogi','Mojeek','Mojolicious \(Perl\)','Monit\/','monitis','Monitority\/','montastic','MonTools','Moreover','Morfeus Fucking Scanner','Morning Paper','MovableType','mowser','Mrcgiguy','MS Web Services Client Protocol','MSFrontPage','mShots','MuckRack\/','muhstik-scan','MVAClient','MxToolbox\/','nagios','Najdi\.si','Name Intelligence','Nameprotect','Navroad','NearSite','Needle','Nessus','Net Vampire','NetAnts','NETCRAFT','NetLyzer','NetMechanic','NetNewsWire','Netpursual','netresearch','NetShelter ContentScan','Netsparker','NetTrack','Netvibes','NetZIP','Neustar WPM','NeutrinoAPI','NewRelicPinger','NewsBlur .*Finder','NewsGator','newsme','newspaper\/','Nexgate Ruby Client','NG-Search','Nibbler','NICErsPRO','Nikto','nineconnections','NLNZ_IAHarvester','Nmap Scripting Engine','node-superagent','node-urllib','node\.io','Nodemeter','NodePing','nominet\.org\.uk','nominet\.uk','Norton-Safeweb','Notifixious','notifyninja','NotionEmbedder','nuhk','nutch','Nuzzel','nWormFeedFinder','nyawc\/','Nymesis','NYU','Ocelli\/','Octopus','oegp','Offline Explorer','Offline Navigator','OgScrper','og-scraper','okhttp','omgili','OMSC','Online Domain Tools','OpenCalaisSemanticProxy','Openfind','OpenLinkProfiler','Openstat\/','OpenVAS','Optimizer','Orbiter','OrgProbe\/','orion-semantics','Outlook-Express','Outlook-iOS','ow\.ly','Owler','ownCloud News','OxfordCloudService','Page Valet','page_verifier','page scorer','page2rss','PageGrabber','PagePeeker','PageScorer','Pagespeed\/','Panopta','panscient','Papa Foto','parsijoo','Pavuk','PayPal IPN','pcBrowser','Pcore-HTTP','Pearltrees','PECL::HTTP','peerindex','Peew','PeoplePal','Perlu -','PhantomJS Screenshoter','PhantomJS\/','Photon\/','phpservermon','Pi-Monster','Picscout','Picsearch','PictureFinder','Pimonster','ping\.blo\.gs','Pingability','PingAdmin\.Ru','Pingdom','Pingoscope','PingSpot','pinterest\.com','Pixray','Pizilla','Plagger\/','Ploetz \+ Zeller','Plukkie','plumanalytics','PocketImageCache','PocketParser','Pockey','POE-Component-Client-HTTP','Polymail\/','Pompos','Porkbun','Port Monitor','postano','PostmanRuntime','PostPost','postrank','PowerPoint\/','Priceonomics Analysis Engine','PrintFriendly','PritTorrent','Prlog','probethenet','Project 25499','prospectb2b','Protopage','ProWebWalker','proximic','PRTG Network Monitor','pshtt, https scanning','PTST ','PTST\/[0-9]+','Pulsepoint XT3 web scraper','Pump','Python-httplib2','python-requests','Python-urllib','Qirina Hurdler','QQDownload','QrafterPro','Qseero','Qualidator','QueryN Metasearch','queuedriver','Quora Link Preview','Qwantify','Radian6','RankActive','RankFlex','RankSonicSiteAuditor','Re-re Studio','ReactorNetty','Readability','RealDownload','RealPlayer%20Downloader','RebelMouse','Recorder','RecurPost\/','redback\/','ReederForMac','Reeder\/','ReGet','RepoMonkey','request\.js','reqwest\/','ResponseCodeTest','RestSharp','Riddler','Rival IQ','Robosourcer','Robozilla','ROI Hunter','RPT-HTTPClient','RSSOwl','safe-agent-scanner','SalesIntelligent','Saleslift','Sendsay\.Ru','SauceNAO','SBIder','scalaj-http','scan\.lol','ScanAlert','Scoop','scooter','ScoutJet','ScoutURLMonitor','ScrapeBox Page Scanner','SimpleScraper','Scrapy','Screaming','ScreenShotService','Scrubby','Scrutiny\/','search\.thunderstone','Search37','searchenginepromotionhelp','Searchestate','SearchExpress','SearchSight','Seeker','semanticdiscovery','semanticjuice','Semiocast HTTP client','Semrush','sentry\/','SEO Browser','Seo Servis','seo-nastroj\.cz','seo4ajax','Seobility','SEOCentro','SeoCheck','SEOkicks','Seomoz','SEOprofiler','SEOsearch','seoscanners','seositecheckup','SEOstats','servernfo','sexsearcher','Seznam','Shelob','Shodan','Shoppimon','ShopWiki','ShortLinkTranslate','shrinktheweb','Sideqik','SimplePie','SimplyFast','Siphon','SISTRIX','Site-Shot\/','Site Sucker','Site24x7','SiteBar','Sitebeam','Sitebulb\/','SiteCondor','SiteExplorer','SiteGuardian','Siteimprove','SiteIndexed','Sitemap(s)? Generator','SitemapGenerator','SiteMonitor','Siteshooter B0t','SiteSnagger','SiteSucker','SiteTruth','Sitevigil','sitexy\.com','SkypeUriPreview','Slack\/','slider\.com','slurp','SlySearch','SmartDownload','SMRF URL Expander','SMUrlExpander','Snake','Snappy','SnapSearch','Snarfer\/','SniffRSS','sniptracker','Snoopy','SnowHaze Search','sogou web','SortSite','Sottopop','sovereign\.ai','SpaceBison','SpamExperts','Spammen','Spanner','spaziodati','SPDYCheck','Specificfeeds','speedy','SPEng','Spinn3r','spray-can','Sprinklr ','spyonweb','sqlmap','Sqlworm','Sqworm','SSL Labs','ssl-tools','StackRambler','Statastico\/','StatusCake','Steeler','Stratagems Kumo','Stroke\.cz','StudioFACA','StumbleUpon','suchen','Sucuri','summify','SuperHTTP','Surphace Scout','Suzuran','SwiteScraper','Symfony BrowserKit','Symfony2 BrowserKit','SynHttpClient-Built','Sysomos','sysscan','Szukacz','T0PHackTeam','tAkeOut','Tarantula\/','Taringa UGC','TarmotGezgin','Teleport','Telesoft','Telesphoreo','Telesphorep','Tenon\.io','teoma','terrainformatica','Test Certificate Info','testuri','Tetrahedron','TextRazor Downloader','The Drop Reaper','The Expert HTML Source Viewer','The Knowledge AI','The Intraformant','theinternetrules','TheNomad','Thinklab','Thumbshots','ThumbSniper','Thumbor','timewe\.net','TinEye','Tiny Tiny RSS','TLSProbe\/','Toata','topster','touche\.com','Traackr\.com','tracemyfile','Trackuity','TrapitAgent','Trendiction','Trendsmap','trendspottr','truwoGPS','TryJsoup','TulipChain','Turingos','Turnitin','tweetedtimes','Tweetminster','Tweezler\/','twibble','Twice','Twikle','Twingly','Twisted PageGetter','Typhoeus','ubermetrics-technologies','uclassify','UdmSearch','unchaos','unirest-java','UniversalFeedParser','Unshorten\.It','Untiny','UnwindFetchor','updated','updown\.io daemon','Upflow','Uptimia','Urlcheckr','URL Verifier','URLitor','urlresolver','Urlstat','URLTester','UrlTrends Ranking Updater','URLy Warning','URLy\.Warning','Vacuum','Vagabondo','VB Project','vBSEO','VCI','via ggpht\.com GoogleImageProxy','VidibleScraper','Virusdie','visionutils','vkShare','VoidEYE','Voil','voltron','voyager\/','VSAgent\/','VSB-TUO\/','Vulnbusters Meter','VYU2','w3af\.org','W3C_Unicorn','W3C-checklink','W3C-mobileOK','WAC-OFU','Wallpapers\/[0-9]+','WallpapersHD','wangling','Wappalyzer','WatchMouse','WbSrch\/','WDT\.io','web-capture\.net','Web-sniffer','Web Auto','Web Collage','Web Enhancer','Web Fetch','Web Fuck','Web Pix','Web Sauger','Web spyder','Web Sucker','Webalta','Webauskunft','WebAuto','WebCapture','WebClient\/','webcollage','WebCookies','WebCopier','WebCorp','WebDataStats','WebDoc','WebEnhancer','WebFetch','WebFuck','WebGazer','WebGo IS','WebImageCollector','WebImages','WebIndex','webkit2png','WebLeacher','webmastercoffee','webmon ','WebPix','WebReaper','WebSauger','webscreenie','Webshag','Webshot','Website Quester','websitepulse agent','WebsiteQuester','Websnapr','WebSniffer','Webster','WebStripper','WebSucker','Webthumb\/','WebThumbnail','WebWhacker','WebZIP','WeLikeLinks','WEPA','WeSEE','wf84','Wfuzz\/','wget','WhatsApp','WhatsMyIP','WhatWeb','WhereGoes\?','Whibse','WhoRunsCoinHive','Whynder Magnet','Windows-RSS-Platform','WinPodder','wkhtmlto','wmtips','Woko','woorankreview','Word\/','WordPress\/','worldping-api','WordupinfoSearch','wotbox','WP Engine Install Performance API','wpif','wprecon\.com survey','WPScan','wscheck','Wtrace','WWW-Collector-E','WWW-Mechanize','WWW::Document','WWW::Mechanize','www\.monitor\.us','WWWOFFLE','x09Mozilla','x22Mozilla','XaxisSemanticsClassifier','Xenu Link Sleuth','XING-contenttabreceiver','xpymep([0-9]?)\.exe','Y!J-(ASR|BSC)','Y\!J-BRW','Yaanb','yacy','Yahoo Link Preview','YahooCacheSystem','YahooYSMcm','YandeG','Yandex(?!Search)','yanga','yeti','Yo-yo','Yoleo Consumer','yoogliFetchAgent','YottaaMonitor','Your-Website-Sucks','yourls\.org','YoYs\.net','YP\.PL','Zabbix','Zade','Zao','Zauba','Zemanta Aggregator','Zend_Http_Client','Zend\\\\Http\\\\Client','Zermelo','Zeus ','zgrab','ZnajdzFoto','ZnHTTP','Zombie\.js','Zoom\.Mac','ZyBorg','[a-z0-9\-_]*(bot|crawl|archiver|transcoder|spider|uptime|validator|fetcher|cron|checker|reader|extractor|monitoring|analyzer)',);

        $regex = '('.implode('|', $data).')';

        preg_match("/{$regex}/i", $_SERVER['HTTP_USER_AGENT'], $matches);

        if (count($matches) > 0){
            return true;
        }else{
            return false;
        }
    }

    static function ucwords_tr($str){
        return ltrim(mb_convert_case(str_replace(array('i','I'), array('İ','ı'),mb_strtolower($str)), MB_CASE_TITLE, 'UTF-8'));
    }

    static function strtoupper_tr($text)
    {
        $search=array("ç","i","ı","ğ","ö","ş","ü");
        $replace=array("Ç","İ","I","Ğ","Ö","Ş","Ü");
        $text=str_replace($search,$replace,$text);
        $text=strtoupper($text);
        return $text;
    }

    static function wc_translator($expression){
        $tmp_array = include base_path().'/lang/tr/tr.php';
        if (!isset($tmp_array[$expression])){
            $tmp_array[$expression] = $expression;
            file_put_contents(base_path().'/lang/tr/tr.php',"<?php\nreturn ".var_export($tmp_array, true).";");
        }
        return __('tr.'.$expression);
    }



    static function soapClientWSSecurityHeader($user, $password)
    {
        $tm_created = gmdate('Y-m-d\TH:i:s\Z');
        $tm_expires = gmdate('Y-m-d\TH:i:s\Z', gmdate('U') + 180);

        $simple_nonce = mt_rand();
        $encoded_nonce = base64_encode($simple_nonce);

        $passdigest = base64_encode(sha1($simple_nonce . $tm_created . $password, true));

        $ns_wsse = 'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd';
        $ns_wsu = 'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd';
        $password_type = 'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-username-token-profile-1.0#PasswordDigest';
        $encoding_type = 'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-soap-message-security-1.0#Base64Binary';

        $root = new \SimpleXMLElement('<root/>');

        $security = $root->addChild('wsse:Security', null, $ns_wsse);

        $timestamp = $security->addChild('wsu:Timestamp', null, $ns_wsu);
        $timestamp->addAttribute('wsu:Id', 'Timestamp-28');
        $timestamp->addChild('wsu:Created', $tm_created, $ns_wsu);
        $timestamp->addChild('wsu:Expires', $tm_expires, $ns_wsu);


        $usernameToken = $security->addChild('wsse:UsernameToken', null, $ns_wsse);
        $usernameToken->addChild('wsse:Username', $user, $ns_wsse);
        $usernameToken->addChild('wsse:Password', $password, $ns_wsse)->addAttribute('Type', $password_type);
        $usernameToken->addChild('wsse:Nonce', $encoded_nonce, $ns_wsse)->addAttribute('EncodingType', $encoding_type);
        $usernameToken->addChild('wsu:Created', $tm_created, $ns_wsu);

        $root->registerXPathNamespace('wsse', $ns_wsse);
        $full = $root->xpath('/root/wsse:Security');
        $auth = $full[0]->asXML();

        return new \SoapHeader($ns_wsse, 'Security', new \SoapVar($auth, XSD_ANYXML), true);
    }

    static function getNameTag($name){
        return substr($name, 0, 1).'.';
    }
}
