<?php

use App\Helpdesk\Helper;
use App\Models\Bank;
use App\Models\City;
use App\Models\District;
use App\Models\Order;
use App\Models\OrderDetail;
use App\Models\Product;
use App\Models\User;
use App\Models\UserAddress;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Iyzipay\HashGenerator;
use Iyzipay\Options;

Route::get('burcu-arslanalp', function () {
    return redirect("https://card.wizzycard.com/c/burcu-arslanalp");
});
Route::get('muhammed-akpinar', function () {
    return redirect("https://card.wizzycard.com/c/muhammed-akpinar");
});
Route::get('kadir-ustun', function () {
    return redirect("https://card.wizzycard.com/c/kadir-ustun");
});

Route::get('/c/{url}', function ($url) {
    return redirect("https://card.wizzycard.com/c/" . $url);
});

Route::get('/', function () {
    $products = Product::with('images')->orderBy('sort')->get();
    return view('welcome')->with('products', $products);
});

Route::get('/products', function () {
    $products = Product::with('images')->orderBy('sort')->get();
    return view('products')->with('products', $products);
});

Route::get('/products/{slug}', function ($slug) {
    $product = Product::with('images')->whereSlug($slug)->first();
    if ($product != null) {
        return view('product')->with('product', $product);
    } else {
        return view('404');
    }
});

Route::post('/add-cart', function (Request $request) {
    DB::beginTransaction();

    if (!Session::has('browser_id')) {
        $uid = Str::uuid();

        while (1) {
            $vcard_tmp = Order::whereBrowserId($uid)->first();

            if ($vcard_tmp != null) {
                $uid = Str::uuid();
            } else {
                break;
            }
        }
        Session::put('browser_id', $uid);
    }

    try {
        if (Auth::check()) {
            $order = Order::whereUserId(Auth::user()->id)->whereStatus(0)->whereProgressPayment(0)->first();
        } else {
            $order = Order::whereBrowserId(Session::get('browser_id'))->whereStatus(0)->whereProgressPayment(0)->first();
        }

        if ($order == null) {
            $order = new Order();
            $order->user_id = Auth::check() ? Auth::user()->id : null;
            $order->browser_id = Session::get('browser_id');

            if (Session::has('reference_code') && Session::has('reference_user_id')) {
                $order->seller_id = Session::get('reference_user_id');
                $order->reference_code = Session::get('reference_code');
            }

            $order->save();
        }

        $order_total = 0;

        for ($i = 0; $i <= $request->order_count; $i++) {
            if ($request->has('product-card-name-input-' . $i)) {
                $order_detail = new OrderDetail();

                if (Session::has('reference_code') && Session::has('reference_user_id')) {
                    $order_detail->seller_id = Session::get('reference_user_id');
                }

                $order_detail->order_id = $order->id;
                $order_detail->user_id = $order->user_id;
                $order_detail->product_id = $request->product_id;
                $order_detail->quantity = ($request->get('product-card-backup-check-' . $i) !== null ? 2 : 1); // Eğer yedek kart varsa quantity 2 olacak
                $order_detail->logo_name = $request->hasFile('product-card-logo-' . $i) ? $request->file('product-card-logo-' . $i)->getClientOriginalName() : '';
                $order_detail->logo = $request->hasFile('product-card-logo-' . $i) ? base64_encode(file_get_contents($request->file('product-card-logo-' . $i)->path())) : null;
                $order_detail->text = $request->get('product-card-name-input-' . $i);
                $order_detail->note = $request->get('product-card-not-' . $i);
                $order_detail->qr = '0';
                $order_detail->rotation = $request->get('yon-secimi-' . $i);

                $product = Product::whereId($request->product_id)->whereStatus(0)->first();

                if ($product != null) {
                    if ($request->get('product-card-backup-check-' . $i) !== null) {
                        // Eğer yedek kart varsa 2 tane ürün var, biri tam fiyat, diğeri %30 indirimli olacak
                        $first_product_price = $product->price; // İlk ürün tam fiyat
                        $second_product_price = $product->price - ($product->price * 0.30); // İkinci ürün %30 indirimli

                        // Total fiyat
                        $order_detail->total = $first_product_price + $second_product_price;
                        $order_detail->net_total = $first_product_price + $second_product_price;

                        // Toplam sipariş fiyatına ekle
                        $order_total += $order_detail->total;
                    } else {
                        // Normal ürün
                        $order_detail->total = $product->price;
                        $order_detail->net_total = $product->price;

                        // Toplam sipariş fiyatına ekle
                        $order_total += $product->price;
                    }

                    // Satır sayısı ve kart sayısını artır
                    $order->line_count += 1;
                    $order->card_count += $order_detail->quantity;

                    // Sipariş detaylarını kaydet
                    $order_detail->order_id = $order->id;
                    $order_detail->save();
                }
            }
        }

        // Sipariş toplamını kaydet
        $order->total = $order_total;
        $order->net_total = $order_total;

        $order->save();

        DB::commit();

        // Sipariş detaylarıyla birlikte döndür
        $cart = Order::whereId($order->id)->with('details')->first();
        return response()->json([
            'status' => true,
            'type' => 'success',
            'message' => 'success',
            'order' => $cart,
        ]);
    } catch (\Exception $exception) {
        DB::rollBack();
        return response()->json([
            'status' => false,
            'type' => 'error',
            'message' => $exception->getMessage(),
        ]);
    }
});


Route::get('/get-cart', function () {

    if (Session::has('browser_id')) {
        if (Auth::check()) {
            $cart = Order::whereUserId(Auth::user()->id)->whereStatus(0)->whereProgressPayment(0)->with('details')->first();
        } else {
            $cart = Order::whereBrowserId(Session::get('browser_id'))->whereStatus(0)->whereProgressPayment(0)->with('details')->first();
        }
        return response()->json([
            'status' => true,
            'type' => 'success',
            'message' => 'success',
            'order' => $cart,
        ]);
    } else {
        return response()->json([
            'status' => false,
            'type' => 'error',
            'message' => 'error',
            'order' => null,
        ]);
    }
});


Route::post('/increase-card', function (Request $request) {
    DB::beginTransaction();

    try {
        // Kullanıcı oturumu kontrol edilir
        if (Auth::check()) {
            $order = Order::whereUserId(Auth::user()->id)->whereStatus(0)->whereProgressPayment(0)->first();
        } else {
            $order = Order::whereBrowserId(Session::get('browser_id'))->whereStatus(0)->whereProgressPayment(0)->first();
        }

        // Eğer sipariş mevcutsa
        if ($order != null) {
            // İlgili sipariş detayı bulunur
            $order_detail = OrderDetail::whereId($request->id)->whereOrderId($order->id)->first();

            if ($order_detail != null) {
                // Ürün miktarı artırılır
                $order_detail->quantity += 1;

                // Toplam ve net toplam yeniden hesaplanır
                $product = Product::whereId($order_detail->product_id)->whereStatus(0)->first();
                if ($product != null) {
                    $extra_cost = $product->price - ($product->price * ($product->discount / 100));

                    $order_detail->total += $extra_cost;
                    $order_detail->net_total += $extra_cost;

                    // Sipariş genel toplamları güncellenir
                    $order->total += $extra_cost;
                    $order->net_total += $extra_cost;

                    // Sipariş ve sipariş detayı kaydedilir
                    $order_detail->save();
                    $order->save();
                }

                DB::commit();
                return response()->json([
                    'status' => true,
                    'type' => 'success',
                    'message' => 'Product quantity increased successfully',
                ]);
            } else {
                return response()->json([
                    'status' => false,
                    'type' => 'error',
                    'message' => 'Order detail not found',
                ]);
            }
        } else {
            return response()->json([
                'status' => false,
                'type' => 'error',
                'message' => 'Order not found',
            ]);
        }
    } catch (\Exception $exception) {
        DB::rollBack();
        return response()->json([
            'status' => false,
            'type' => 'error',
            'message' => $exception->getMessage(),
        ]);
    }
});



Route::post('/remove-card', function (Request $request) {
    DB::beginTransaction();

    try {

        if (Auth::check()) {
            $order = Order::whereUserId(Auth::user()->id)->whereStatus(0)->whereProgressPayment(0)->first();
        } else {
            $order = Order::whereBrowserId(Session::get('browser_id'))->whereStatus(0)->whereProgressPayment(0)->first();
        }

        if ($order != null) {

            $order_detail = OrderDetail::whereId($request->id)->whereOrderId($order->id)->first();

            if ($order_detail != null) {


                if ($order_detail->quantity > 1) {

                    $order_detail->quantity -= 1;


                    $product = Product::whereId($order_detail->product_id)->first();
                    if ($product != null) {
                        $extra_cost = $product->price - ($product->price * ($product->discount / 100));


                        $order_detail->total -= $extra_cost;
                        $order_detail->net_total -= $extra_cost;
                        $order->total -= $extra_cost;
                        $order->net_total -= $extra_cost;


                        $order_detail->save();
                        $order->save();
                    }

                    DB::commit();
                    return response()->json([
                        'status' => true,
                        'type' => 'success',
                        'message' => 'Product quantity decreased successfully',
                    ]);
                } else {

                    $order->total -= $order_detail->total;
                    $order->net_total -= $order_detail->net_total;
                    $order->line_count -= 1;
                    $order->card_count -= 1;


                    $order_detail->delete();


                    if ($order->line_count == 0) {
                        $order->status = 9;
                        $order->save();
                    } else {
                        $order->save();
                    }

                    DB::commit();
                    return response()->json([
                        'status' => true,
                        'type' => 'success',
                        'message' => 'Product removed successfully',
                    ]);
                }
            } else {
                return response()->json([
                    'status' => false,
                    'type' => 'error',
                    'message' => 'Order detail not found',
                ]);
            }
        } else {
            return response()->json([
                'status' => false,
                'type' => 'error',
                'message' => 'Order not found',
            ]);
        }
    } catch (\Exception $exception) {
        DB::rollBack();
        return response()->json([
            'status' => false,
            'type' => 'error',
            'message' => $exception->getMessage(),
        ]);
    }
});




Route::get('/cart/{error?}', function ($error = false) {
    if (Session::has('browser_id')) {
        if (Auth::check()) {
            $cart = Order::whereUserId(Auth::user()->id)->whereStatus(0)->whereProgressPayment(0)->with('details')->first();
        } else {
            $cart = Order::whereBrowserId(Session::get('browser_id'))->whereStatus(0)->whereProgressPayment(0)->with('details')->first();
        }
        $cities = City::get();
        $districts = District::get();
        $banks = Bank::get();
        return view('cart')->with([
            'cart' => $cart,
            'cities' => $cities,
            'districts' => $districts,
            'banks' => $banks,
            'error' => $error
        ]);
    } else {
        return redirect('/products');
    }
});

Route::post('/cart', function (Request $request) {
    $valid_array = $request->all();

    if (isset($valid_array["phone"])) {
        $valid_array["phone"] = preg_replace('/\D+/', '', str_replace(' ', '', $valid_array["phone"]));
        if (str_starts_with($valid_array["phone"], "90")) {
            $valid_array["phone"] = substr($valid_array["phone"], 2);
        }
        if (str_starts_with($valid_array["phone"], "0")) {
            $valid_array["phone"] = substr($valid_array["phone"], 1);
        }
    }

    $validator = Validator::make($valid_array, [
        'name' => 'required',
        'surname' => 'required',
        'email' => 'required',
        'phone' => 'required',
        'city_id' => 'required',
        'district_id' => 'required',
        'address' => 'required',
        'invoice_type' => 'required',
        'invoice_name' => 'required',
        'tax_number' => 'required',
        'tax_office' => 'required_if:invoice_type,==,1',
        'invoice_city_id' => 'required_if:different_address,==,1',
        'invoice_district_id' => 'required_if:different_address,==,1',
        'invoice_address' => 'required_if:different_address,==,1',
        //'payment_type' => 'required',
        'card_name' => 'required',
        'card_number' => 'required',
        'expire_date' => 'required',
        'cvv' => 'required',
    ], [
        'name' => 'Ad boş bırakılamaz.',
        'surname' => 'Soyad boş bırakılamaz.',
        'email.required' => 'E-posta boş bırakılamaz.',
        'phone.required' => 'Telefon boş bırakılamaz.',
        'city_id' => 'İl boş bırakılamaz.',
        'district_id' => 'İlçe boş bırakılamaz.',
        'address' => 'Adres boş bırakılamaz.',
        'invoice_type' => 'Fatura Tipi boş bırakılamaz.',
        'invoice_name' => 'Fatura Adı boş bırakılamaz.',
        'tax_number' => 'T.C. Kimlik No veya Vergi No boş bırakılamaz.',
        'tax_office' => 'Vergi Dairesi boş bırakılamaz.',
        'invoice_city_id' => 'Fatura İl boş bırakılamaz.',
        'invoice_district_id' => 'Fatura İlçe boş bırakılamaz.',
        'invoice_address' => 'Fatura Adresi boş bırakılamaz.',
        //'payment_type' => 'Ödeme Tip boş bırakılamaz.',
        'card_name' => 'Kart Sahibinin Adı boş bırakılamaz.',
        'card_number' => 'Kart Numarası boş bırakılamaz.',
        'expire_date' => 'Son Kullanma Tarihi boş bırakılamaz.',
        'cvv' => 'CVV Kodu boş bırakılamaz.',
    ]);

    if ($validator->fails()) {
        return response([
            "type" => "error",
            "title" => "Doğrulama Hatası",
            "message" => $validator->errors()->first()
        ]);
    } else {
        try {
            DB::beginTransaction();

            $basketItems = array();
            $totalAidat = 0;
            if (Auth::check()) {
                $user = User::whereId(Auth::user()->id)->first();
            } else {
                $user = User::wherePhone($valid_array["phone"])->first();

                if ($user == null) {
                    $user = new User();

                    $user->name = $request->name;
                    $user->surname = $request->surname;
                    $user->email = $request->email;
                    $user->phone = $valid_array["phone"];

                    $password = Helper::randomString(8);

                    $user->password = Hash::make($password);

                    $user->save();
                }
            }

            if (!Session::has('browser_id')) {
                $uid = Str::uuid();

                while (1) {
                    $vcard_tmp = Order::whereBrowserId($uid)->first();

                    if ($vcard_tmp != null) {
                        $uid = Str::uuid();
                    } else {
                        break;
                    }
                }
                Session::put('browser_id', $uid->toString());
            }

            if (Auth::check()) {
                $order = Order::whereUserId(Auth::user()->id)->whereStatus(0)->whereProgressPayment(0)->whereId($request->order_id)->with('details')->first();
            } else {
                $order = Order::whereBrowserId(Session::get('browser_id'))->whereStatus(0)->whereProgressPayment(0)->whereId($request->order_id)->with('details')->first();
            }

            if (!isset($request->user_address_id)) {
                $address = new UserAddress();

                $address->user_id = $user->id;
                $address->different_address = isset($request->different_address) ? '1' : '0';
                $address->name_surname = $request->invoice_name;
                $address->phone = $valid_array["phone"];
                $address->email = $request->email;
                $address->address = $request->address;
                $address->city_id = $request->city_id;
                $address->district_id = $request->district_id;
                $address->invoice_type = $request->invoice_type;
                $address->invoice_name = $request->invoice_name;
                $address->tax_number = $request->tax_number;
                $address->tax_office = $request->tax_office;
                $address->invoice_address = $request->invoice_address;
                $address->invoice_city_id = $request->invoice_city_id;
                $address->invoice_district_id = $request->invoice_district_id;

                $address->save();
            } else {
                $address = UserAddress::whereId($request->user_address_id)->whereUserId($user->id)->first();
            }

            $order->user_id = $user->id;
            $order->user_address_id = $address->id;

            $order->save();

            foreach ($order->details as $order_item) {

                $product = Product::whereId($order_item->product_id)->whereStatus(0)->with('category')->first();

                $basketItem = new \Iyzipay\Model\BasketItem();
                $basketItem->setId($product->id);
                $basketItem->setName($product->name);
                $basketItem->setCategory1($product->category->name);
                $basketItem->setItemType(\Iyzipay\Model\BasketItemType::PHYSICAL);
                $basketItem->setPrice($product->price);

                $basketItems[] = $basketItem;

                if ($order_item->quantity > 1) {
                    for ($i = 0; $i < ($order_item->quantity - 1); $i++) {
                        $basketItem = new \Iyzipay\Model\BasketItem();
                        $basketItem->setId($order_item->id);
                        $basketItem->setName($product->name);
                        $basketItem->setCategory1($product->category->name);
                        $basketItem->setItemType(\Iyzipay\Model\BasketItemType::PHYSICAL);
                        $basketItem->setPrice($product->price - ($product->price * ($product->discount / 100)));


                        $basketItems[] = $basketItem;
                    }
                }

                $totalAidat += 200 * $order_item->quantity;

                if ($order_item->package == '1') {
                    $basketItem = new \Iyzipay\Model\BasketItem();
                    $basketItem->setId($order_item->id);
                    $basketItem->setName("Profesyonel Paket");
                    $basketItem->setCategory1("Profesyonel Paket");
                    $basketItem->setItemType(\Iyzipay\Model\BasketItemType::VIRTUAL);
                    $basketItem->setPrice(200);

                    $basketItems[] = $basketItem;
                }
            }
            $totalPrice = $order->total + $totalAidat;
            $options = new Options();
            /*$options->setApiKey('0HBTqUsJSAoOt4ZC215cKVL0THwYYftC');
            $options->setSecretKey('E5NO26U1CU2xGoggHe81SSTphWsUo4sN');
            $options->setBaseUrl('https://api.iyzipay.com');
            */
            $options->setApiKey('sandbox-LGjhTTxfS282TQt21b2twW14L9Z2kgSh');
            $options->setSecretKey('sandbox-6Znhh8cc5TwmZCc6l2wOBv7owksZjm3j');
            $options->setBaseUrl('https://sandbox-api.iyzipay.com');

            $req = new \Iyzipay\Request\CreatePaymentRequest();
            $req->setLocale(\Iyzipay\Model\Locale::TR);
            $req->setConversationId($order->id);
            $req->setPrice($order->total);
            $req->setPaidPrice($totalPrice);
            $req->setCurrency(\Iyzipay\Model\Currency::TL);
            $req->setInstallment(1);
            $req->setBasketId($order->id);
            $req->setPaymentChannel(\Iyzipay\Model\PaymentChannel::WEB);
            $req->setPaymentGroup(\Iyzipay\Model\PaymentGroup::PRODUCT);
            $req->setCallbackUrl("https://wizzycard.com/order-finish/" . $order->id);

            $paymentCard = new \Iyzipay\Model\PaymentCard();
            $paymentCard->setCardHolderName($request->card_name);
            $paymentCard->setCardNumber(str_replace(' ', '', $request->card_number));
            $paymentCard->setExpireMonth(explode('/', $request->expire_date)[0]);
            $paymentCard->setExpireYear("20" . explode('/', $request->expire_date)[1]);
            $paymentCard->setCvc($request->cvv);
            $paymentCard->setRegisterCard(0);
            $req->setPaymentCard($paymentCard);

            $city = City::whereId($address->city_id)->first();
            $district = District::whereId($address->district_id)->first();

            $buyer = new \Iyzipay\Model\Buyer();
            $buyer->setId($user->id);
            $buyer->setName($user->name);
            $buyer->setSurname($user->surname);
            $buyer->setGsmNumber($user->phone);
            $buyer->setEmail($user->email);
            $buyer->setIdentityNumber($address->tax_number);
            $buyer->setRegistrationAddress($address->address);
            $buyer->setIp(!empty($_SERVER['HTTP_CF_CONNECTING_IP']) ? $_SERVER['HTTP_CF_CONNECTING_IP'] : $_SERVER['REMOTE_ADDR']);
            $buyer->setCity($city->name);
            $buyer->setCountry("Turkey");
            $req->setBuyer($buyer);

            $shippingAddress = new \Iyzipay\Model\Address();
            $shippingAddress->setContactName($address->name_surname);
            $shippingAddress->setCity($city->name);
            $shippingAddress->setCountry("Turkey");
            $shippingAddress->setAddress($address->address . ', ' . $district->name . ', ' . $city->name);
            $req->setShippingAddress($shippingAddress);

            $billingAddress = new \Iyzipay\Model\Address();
            $billingAddress->setContactName($address->invoice_name);
            if ($address->different_address == "0") {
                $billingAddress->setCity($city->name);
                $billingAddress->setCountry("Turkey");
                $billingAddress->setAddress($address->address . ', ' . $district->name . ', ' . $city->name);
            } else {
                $invoice_city = City::whereId($address->invoice_city_id)->first();
                $invoice_district = District::whereId($address->invoice_district_id)->first();

                $billingAddress->setCity($invoice_city->name);
                $billingAddress->setCountry("Turkey");
                $billingAddress->setAddress($address->address . ', ' . $invoice_district->name . ', ' . $invoice_city->name);
            }
            $req->setBillingAddress($billingAddress);

            $req->setBasketItems($basketItems);

            //$payment = \Iyzipay\Model\ThreedsInitialize::create($req, $options);

            $curl = curl_init();

            $rnd = uniqid();
            $authContent = HashGenerator::generateHash($options->getApiKey(), $options->getSecretKey(), $rnd, $req);

            curl_setopt_array($curl, array(
                CURLOPT_URL => 'https://sandbox-api.iyzipay.com/payment/3dsecure/initialize',
                //CURLOPT_URL => 'https://api.iyzipay.com/payment/3dsecure/initialize',
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => '',
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 0,
                CURLOPT_FOLLOWLOCATION => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => 'POST',
                CURLOPT_POSTFIELDS => $req->toJsonString(),
                CURLOPT_HTTPHEADER => array(
                    'Authorization: ' . vsprintf("IYZWS %s:%s", array($options->getApiKey(), $authContent)),
                    'x-iyzi-rnd: ' . $rnd,
                    'Content-Type: application/json'
                ),
            ));

            curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, FALSE);
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);

            $response = json_decode(curl_exec($curl));

            curl_close($curl);

            if (!isset($response->threeDSHtmlContent)) {
                DB::rollBack();
                return response([
                    "type" => "error",
                    "title" => "Ödeme Hatası",
                    "message" => "Ödeme işleminde bir hata gerçekleşti. Lütfen bilgilerinizi kontrol ederek tekrar deneyiniz."
                ]);
            } else {
                DB::commit();
                return response([
                    'type' => 'success',
                    "title" => "İşlem Başarılı",
                    "message" => "Ödeme ekranına yönlendiriliyorsunuz.",
                    "htmlContent" => base64_decode($response->threeDSHtmlContent)
                ]);
            }
        } catch (\Exception $exception) {
            DB::rollBack();
            return response([
                'type' => 'error',
                'title' => 'Sistemsel Hata',
                'message' => "Sistemsel bir hata gerçekleşti. Lütfen daha sonra tekrar deneyiniz."
            ]);
        }
    }
});

Route::post('/order-finish/{id}', function ($id, Request $request) {
    $order = Order::whereId($id)->first();

    //return response()->json($request);

    if ($order != null) {
        $user = User::whereId($order->user_id)->first();

        Session::put('browser_id', $order->browser_id);

        if ($request->status == 'success') {
            $options = new Options();
            //$options->setApiKey('0HBTqUsJSAoOt4ZC215cKVL0THwYYftC');
            //$options->setSecretKey('E5NO26U1CU2xGoggHe81SSTphWsUo4sN');
            //$options->setBaseUrl('https://api.iyzipay.com');
            $options->setApiKey('sandbox-LGjhTTxfS282TQt21b2twW14L9Z2kgSh');
            $options->setSecretKey('sandbox-6Znhh8cc5TwmZCc6l2wOBv7owksZjm3j');
            $options->setBaseUrl('https://sandbox-api.iyzipay.com');

            $req = new \Iyzipay\Request\CreateThreedsPaymentRequest();
            $req->setLocale(\Iyzipay\Model\Locale::TR);
            $req->setConversationId($request->conversationId);
            $req->setPaymentId($request->paymentId);
            $req->setConversationData($request->conversationData);

            $curl = curl_init();

            $rnd = uniqid();
            $authContent = HashGenerator::generateHash($options->getApiKey(), $options->getSecretKey(), $rnd, $req);

            curl_setopt_array($curl, array(
                CURLOPT_URL => 'https://sandbox-api.iyzipay.com/payment/3dsecure/auth',
                //CURLOPT_URL => 'https://api.iyzipay.com/payment/3dsecure/auth',
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => '',
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 0,
                CURLOPT_FOLLOWLOCATION => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => 'POST',
                CURLOPT_POSTFIELDS => '{
                "paymentId": "' . $request->paymentId . '",
                "locale": "' . \Iyzipay\Model\Locale::TR . '",
                "conversationId": "' . $request->conversationId . '"
                 }',
                CURLOPT_HTTPHEADER => array(
                    'Authorization: ' . vsprintf("IYZWS %s:%s", array($options->getApiKey(), $authContent)),
                    'x-iyzi-rnd: ' . $rnd,
                    'Content-Type: application/json'
                ),
            ));

            curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, FALSE);
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);

            $response = json_decode(curl_exec($curl));

            curl_close($curl);

            //$threedsPayment = \Iyzipay\Model\ThreedsPayment::create($req, $options);

            //if ($response->mdStatus == '1'){
            if ($response->status == 'success') {
                //Helper::send_sms($user->id, $user->phone, 'WizzyCard dünyasına hoşgeldiniz. Siparişiniz işleme alınmıştır. En kısa sürede bilgilendirileceksiniz.');

                $order->payment = 1;
                $order->status = 2;

                $order->save();

                return redirect('/order-success')->with([
                    'type' => 'success',
                    'title' => 'İşlem Başarılı',
                    'desc' => 'Siparişiniz işleme alındı. En kısa sürede bilgilendirme mesajı alacaksınız.'
                ]);
            } else {
                return redirect('/cart/error')->with([
                    'type' => 'error',
                    'title' => 'Ödeme Hatası',
                    'desc' => 'Ödeme alınamadı. Lütfen kart bilgilerinizi kontrol ederek tekrar deneyiniz.'
                ]);
            }
        } else {
            return redirect('/cart/error')->with([
                'type' => 'error',
                'title' => 'Ödeme Hatası',
                'desc' => 'Ödeme alınamadı. Lütfen kart bilgilerinizi kontrol ederek tekrar deneyiniz.'
            ]);
        }
    } else {
        return redirect('/cart/error')->with([
            'type' => 'error',
            'title' => 'Hata',
            'desc' => 'Sipariş bulunamadı.'
        ]);
    }
});

Route::get('/order-success', function () {
    return view('order-success');
});

Route::get('/corporate', function () {
    return view('corporate');
});

Route::get('/how-it-work', function () {
    return view('how-it-work');
});

Route::get('/faq', function () {
    return view('faq');
});

Route::get('/contact', function () {
    return view('contact');
});

Route::get('/blogs', function () {
    return view('blogs');
});

Route::get('phpinfo', function () {
    return phpinfo();
});

Route::get('curl', function () {

});
